@@ -16,6 +16,9 @@
 # You should have received a copy of the GNU Lesser General Public License along
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 
-remove_cube('file')
+sync_schema_props_perms('QuestionnaireRun')
+sync_schema_props_perms('Questionnaire')
+sync_schema_props_perms('Question')
 
-drop_attribute('QuestionnaireRun', 'identifier')
+sync_schema_props_perms(('Answer', 'question', 'Question'))
+sync_schema_props_perms(('Answer', 'questionnaire_run', 'QuestionnaireRun'))
