@@ -17,7 +17,7 @@
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 
 from cubicweb.web import facet
-from cubicweb.selectors import is_instance
+from cubicweb.predicates import is_instance
 
 
 class QuestionnaireRunQuestionnaireFacet(facet.RelationFacet):
